==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/CMethod__24StmtInfo.h <==
// class org.dellroad.jc.cgen.CMethod$StmtInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 131b00c953457759 org_dellroad_jc_cgen_CMethod__24StmtInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_CMethod__24StmtInfo_H_
#define _JC_org_dellroad_jc_cgen_CMethod__24StmtInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object;

typedef const struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods	org_dellroad_jc_cgen_CMethod__24StmtInfo;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs {
    _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs	org_dellroad_jc_cgen_CMethod__24StmtInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs {
	jchar	javaLineNumber;
	jboolean	branchTarget;
	jboolean	trapBoundary;
	jboolean	backwardTrapTarget;
	jint	lineNumberIndex;
	jshort	labelIndex;
	jshort	region;
	jboolean	needsRegionUpdate;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs	org_dellroad_jc_cgen_CMethod__24StmtInfo;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object {
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_CMethod__24StmtInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_CMethod__24StmtInfo_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/CMethod__24StmtInfo.h <==
// class org.dellroad.jc.cgen.CMethod$StmtInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 131b00c953457759 org_dellroad_jc_cgen_CMethod__24StmtInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_CMethod__24StmtInfo_H_
#define _JC_org_dellroad_jc_cgen_CMethod__24StmtInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object;

typedef const struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vmethods	org_dellroad_jc_cgen_CMethod__24StmtInfo;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs {
    _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_refs	org_dellroad_jc_cgen_CMethod__24StmtInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs {
	jchar	javaLineNumber;
	jboolean	branchTarget;
	jboolean	trapBoundary;
	jboolean	backwardTrapTarget;
	jint	lineNumberIndex;
	jshort	labelIndex;
	jshort	region;
	jboolean	needsRegionUpdate;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$sub_nonrefs	org_dellroad_jc_cgen_CMethod__24StmtInfo;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$object {
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$vtype _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_CMethod__24StmtInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_CMethod__24StmtInfo$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_CMethod__24StmtInfo_H_ */
